------------------------ COPYRIGHT STATEMENT ----------------------------
--
-- Licensed Materials - Property of IBM
-- 5724-C40
-- (C) Copyright IBM Corp. 2002.  All Rights Reserved.
--
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with
-- IBM Corp.
--
------------------------END OF COPYRIGHT STATEMENT -----------------------
--------------------------------------------------------------------------
-- CMVC Location: src/com/tivoli/managed/install/database/migration/m-datamart.db2, database, slm1.2.1.fp1
-- Version:       1.5
-- Last Modified: 8/9/02
--------------------------------------------------------------------------
UPDATE DYK.SCHEMA_VER SET VER='1.15';

ALTER TABLE DYK.EXTRACT_LOG ADD DC_PROCESSED_DTTM TIMESTAMP;

CREATE TABLE DYK.MSMT_AVL (
    MSMT_ID             BIGINT NOT NULL,
    MSMTTYP_ID          INTEGER NOT NULL,
    MSMTTYP_NM          VARCHAR(120) NOT NULL,
    COMP_ID             INTEGER NOT NULL,
    COMP_NM             VARCHAR(254),
    COMPTYP_CD          CHAR(17) NOT NULL,
    TMSUM_CD            CHAR NOT NULL,
    MSMT_ST             TIMESTAMP NOT NULL,
    MSMT_TOT_VAL        FLOAT,
    MSMT_SMPL_CNT       INTEGER,
    MSMT_ERR_CNT        INTEGER,
    DM_ENTRY_TIME       TIMESTAMP DEFAULT CURRENT TIMESTAMP,
    LATE_DATA           SMALLINT DEFAULT 0,   
    PRIMARY KEY (MSMT_ID)
) IN DM_RGLR;

INSERT INTO DYK.EVALUATOR_TABLE (EVAL_NM, TABLE_NM) VALUES ('EVAL_TYPE_C', 'MSMT_AVL');

CREATE INDEX I_AVL_COMP_NM ON DYK.MSMT_AVL (COMP_NM);
CREATE INDEX I_AVL_MSMTTYP_ID ON DYK.MSMT_AVL (MSMTTYP_ID);
CREATE INDEX I_AVL_COMP_ID ON DYK.MSMT_AVL (COMP_ID);
CREATE INDEX I_AVL_MSMT_ST ON DYK.MSMT_AVL (MSMT_ST);
CREATE INDEX I_AVL_TMSUM_CD ON DYK.MSMT_AVL (TMSUM_CD);
CREATE INDEX I_AVL_COMPTYP_CD ON DYK.MSMT_AVL (COMPTYP_CD);
CREATE INDEX I_AVL_MSMTTYP_NM ON DYK.MSMT_AVL (MSMTTYP_NM);
CREATE INDEX I_COMP_ID ON DYK.COMPPATH (Comp_ID);

CREATE TRIGGER DYK.PRUNE_AVL
   AFTER INSERT ON DYK.EXP_LOG
   REFERENCING NEW AS N
   FOR EACH ROW
   MODE DB2SQL

   DELETE FROM DYK.MSMT_AVL M
   WHERE (CURRENT DATE - DATE(M.MSMT_ST)) > N.PURGE_LEN;

--
-- Create a new MMA table with revised datatypes.
--
CREATE TABLE DYK.MMA_NEW (
    MSMT_ID             BIGINT NOT NULL,
    MSMTTYP_ID          INTEGER NOT NULL,
    COMP_ID             INTEGER NOT NULL,
    COMP_NM             VARCHAR(254),
    COMPTYP_CD          CHAR(17) NOT NULL,
    TMSUM_CD            CHAR NOT NULL,
    MSMT_ST             TIMESTAMP NOT NULL,
    MSMT_MIN_VAL        FLOAT,
    MSMT_MAX_VAL        FLOAT,
    MSMT_AVG_VAL        FLOAT,
    MSMT_SMPL_CNT       INTEGER,
    MSMT_ERR_CNT        INTEGER,
    DM_ENTRY_TIME       TIMESTAMP DEFAULT CURRENT TIMESTAMP,
    LATE_DATA           SMALLINT DEFAULT 0,
    PRIMARY KEY (MSMT_ID)
) IN DM_RGLR;

--
-- Move existing MMA MSMT data into new table.
--
INSERT INTO DYK.MMA_NEW (SELECT * FROM DYK.MSMT_MMA);

--
-- Drop old MMA table.
--
DROP TABLE DYK.MSMT_MMA;

--
-- Rename the new table to original name.
--
RENAME TABLE DYK.MMA_NEW TO MSMT_MMA;

--
-- Recreate the necessary indexes that were dropped when the
-- MMA table was dropped.
--
CREATE INDEX I_MMA_COMP_NM ON DYK.MSMT_MMA (COMP_NM);
CREATE INDEX I_MMA_MSMTTYP_ID ON DYK.MSMT_MMA (MSMTTYP_ID);
CREATE INDEX I_MMA_COMP_ID ON DYK.MSMT_MMA (COMP_ID);
CREATE INDEX I_MMA_MSMT_ST ON DYK.MSMT_MMA (MSMT_ST);
CREATE INDEX I_MMA_TMSUM_CD ON DYK.MSMT_MMA (TMSUM_CD);
CREATE INDEX I_MMA_COMPTYP_CD ON DYK.MSMT_MMA (COMPTYP_CD);

--
-- Create a new TOT table with revised datatypes.
--
CREATE TABLE DYK.TOT_NEW (
    MSMT_ID             BIGINT NOT NULL,
    MSMTTYP_ID          INTEGER NOT NULL,
    COMP_ID             INTEGER NOT NULL,
    COMP_NM             VARCHAR(254),
    COMPTYP_CD          CHAR(17) NOT NULL,
    TMSUM_CD            CHAR NOT NULL,
    MSMT_ST             TIMESTAMP NOT NULL,
    MSMT_TOT_VAL        FLOAT,
    MSMT_SMPL_CNT       INTEGER,
    MSMT_ERR_CNT        INTEGER,
    DM_ENTRY_TIME       TIMESTAMP DEFAULT CURRENT TIMESTAMP,
    LATE_DATA           SMALLINT DEFAULT 0,   
    PRIMARY KEY (MSMT_ID)
) IN DM_RGLR;

--
-- Move existing TOT MSMT data into new table.
--
INSERT INTO DYK.TOT_NEW (SELECT * FROM DYK.MSMT_TOT);

--
-- Drop old TOT table.
--
DROP TABLE DYK.MSMT_TOT;

--
-- Rename the new table to original name.
--
RENAME TABLE DYK.TOT_NEW TO MSMT_TOT;

--
-- Recreate the necessary indexes that were dropped when the
-- TOT table was dropped.
--
CREATE INDEX I_TOT_COMP_NM ON DYK.MSMT_TOT (COMP_NM);
CREATE INDEX I_TOT_MSMTTYP_ID ON DYK.MSMT_TOT (MSMTTYP_ID);
CREATE INDEX I_TOT_COMP_ID ON DYK.MSMT_TOT (COMP_ID);
CREATE INDEX I_TOT_MSMT_ST ON DYK.MSMT_TOT (MSMT_ST);
CREATE INDEX I_TOT_TMSUM_CD ON DYK.MSMT_TOT (TMSUM_CD);
CREATE INDEX I_TOT_COMPTYP_CD ON DYK.MSMT_TOT (COMPTYP_CD);

--
-- Create a new extract log table with revised datatypes.
--
CREATE TABLE DYK.LOG_NEW (
    COMPLETE_TM         TIMESTAMP NOT NULL DEFAULT CURRENT TIMESTAMP,
    START_RANGE         BIGINT NOT NULL,
    END_RANGE           BIGINT NOT NULL,
    DC_PROCESSED_DTTM   TIMESTAMP,
    PRIMARY KEY (COMPLETE_TM, START_RANGE, END_RANGE)
);

--
-- Move existing extract log data into new table.
--
INSERT INTO DYK.LOG_NEW (SELECT * FROM DYK.EXTRACT_LOG);

--
-- Drop old extract log table.
--
DROP TABLE DYK.EXTRACT_LOG;

--
-- Rename the new table to original name.
--
RENAME TABLE DYK.LOG_NEW TO EXTRACT_LOG;




