------------------------ COPYRIGHT STATEMENT ----------------------------
--
-- Licensed Materials - Property of IBM
-- 5724-C40
-- (C) Copyright IBM Corp. 2002.  All Rights Reserved.
--
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with
-- IBM Corp.
--
------------------------END OF COPYRIGHT STATEMENT -----------------------
--------------------------------------------------------------------------
-- CMVC Location: src/com/tivoli/managed/install/database/migration/m-sdcTables.db2, servcat, slm1.2.1.fp1
-- Version:       1.28
-- Last Modified: 8/21/02
--------------------------------------------------------------------------
UPDATE MM.SCHEMA_VER SET VERSION='1.10';

CREATE TABLE SCHEDULE_STATE
(
	STATE_KEY	VARCHAR(30) NOT NULL,
	LOCALE          VARCHAR(30) NOT NULL,
	STATE_VALUE	VARCHAR(100),
	CONSTRAINT SCHEDULE_STATE_PK PRIMARY KEY (STATE_KEY, LOCALE)
);

CREATE TABLE QUARTER_DATE
(
	QUARTER		INTEGER		NOT NULL,
	START_DATE	TIMESTAMP	NOT NULL
);

INSERT INTO QUARTER_DATE VALUES (1, '2002-01-01-12.00.00.000000');
INSERT INTO QUARTER_DATE VALUES (2, '2002-04-01-12.00.00.000000');
INSERT INTO QUARTER_DATE VALUES (3, '2002-07-01-12.00.00.000000');
INSERT INTO QUARTER_DATE VALUES (4, '2002-10-01-12.00.00.000000');

CREATE TABLE SCHEDULE_HIERARCHY
(
	PARENT_SCHEDULE	BIGINT, 
	CHILD_SCHEDULE	BIGINT,
	ORDER           SMALLINT NOT NULL,
	CONSTRAINT PARENT_SCHED_FK FOREIGN KEY (PARENT_SCHEDULE) REFERENCES SCHEDULE (SCHEDULE_ID) ON DELETE CASCADE,
	CONSTRAINT CHILD_SCHED_FK  FOREIGN KEY (CHILD_SCHEDULE)  REFERENCES SCHEDULE (SCHEDULE_ID) ON DELETE CASCADE
);

CREATE TABLE TABLE_LOCK
(
    TABLE_NUMBER     INTEGER NOT NULL,
    HLOCK            BIGINT,
    SLOCK            BIGINT,
    SLOCK_EXPIRE     TIMESTAMP,
    CONSTRAINT TABLE_LOCK_PK PRIMARY KEY (TABLE_NUMBER)
);

INSERT INTO TABLE_LOCK (TABLE_NUMBER) VALUES (160);
INSERT INTO TABLE_LOCK (TABLE_NUMBER) VALUES (161);

create view svc_offrg_view as
select svc_offrg.*,
	offrg_elmt.offrg_elmt_id,
	offrg_elmt.svc_elmt_id,
	offrg_elmt.sem_id,
	offrg_elmt.offrg_elmt_name,
	offrg_elmt.offrg_elmt_description
from svc_offrg
left outer join offrg_elmt
on svc_offrg.svc_offrg_id = offrg_elmt.svc_offrg_id;

create view schedule_state_view (order, schedule_id, priority, schedule_state, is_repeated, sch_date_bit_str, start_time, end_time, timezn, last_modified) as
select schedule_hierarchy.order,
	schedule.schedule_id,
	schedule_period.priority,
	schedule_period.schedule_state,
	schedule_period.is_repeated,
	schedule_period.sch_date_bit_str,
	schedule_period.start_time,
	schedule_period.end_time,
	schedule_period.timezn,
	schedule.last_modified
from schedule,schedule_period, schedule_hierarchy
where schedule.schedule_id = schedule_hierarchy.parent_schedule
	and schedule_hierarchy.child_schedule = schedule_period.schedule_id
union
select -1,
	schedule_period.*
from schedule, schedule_period
where schedule.schedule_id = schedule_period.schedule_id;

ALTER TABLE OFFERING_ORDER
ADD START_TIME TIMESTAMP NOT NULL WITH DEFAULT CURRENT TIMESTAMP
ADD END_TIME TIMESTAMP
DROP PRIMARY KEY
ADD CONSTRAINT OFFERING_ORDER_PK PRIMARY KEY (SVC_OFFRG_ID, ORDER_ID, START_TIME);

ALTER TABLE SCHEDULE
ADD GLOBAL SMALLINT NOT NULL WITH DEFAULT 0;

ALTER TABLE CUST_ORDER
ADD CUST_ORDER_DESC VARCHAR(1024);

UPDATE CUST_ORDER SET START_TIME = LAST_MODIFIED;

ALTER TABLE USER_INFO
ALTER PASSWORD SET DATA TYPE VARCHAR(255);

-- Move TREND table data to new format using staging table
CREATE TABLE STG_TREND(
    CUST_ORDER_ID      BIGINT         NOT NULL,
    PROP_ID            BIGINT         NOT NULL,
    SCHEDULE_STATE     VARCHAR(32)    NOT NULL,
    COMPONENT_NAME     VARCHAR(127)   NOT NULL,
    ORDER_ELMT_ID      BIGINT         NOT NULL,
    DETECTION_DATE     TIMESTAMP,
    LAST_MODIFIED      TIMESTAMP,
    MIN_PROJ_STATE     SMALLINT,
    AVG_PROJ_STATE     SMALLINT,
    MAX_PROJ_STATE     SMALLINT,
    MIN_PROJ_DATE      TIMESTAMP,
    AVG_PROJ_DATE      TIMESTAMP,
    MAX_PROJ_DATE      TIMESTAMP,
    TAP_START_DATE     TIMESTAMP,
    TAP_END_DATE       TIMESTAMP,
    TAP_TOT_DATA_PTS   INTEGER,
    TREND_TYPE         SMALLINT       NOT NULL,
    CONSTRAINT TREND_PROP FOREIGN KEY (PROP_ID) REFERENCES PROP_DEF (PROP_ID),
    CONSTRAINT TREND_OE FOREIGN KEY (ORDER_ELMT_ID) REFERENCES ORDER_ELMT (ORDER_ELMT_ID) ON DELETE RESTRICT ON UPDATE RESTRICT,
    CONSTRAINT TREND_CO FOREIGN KEY (CUST_ORDER_ID) REFERENCES CUST_ORDER (CUST_ORDER_ID) ON DELETE RESTRICT ON UPDATE RESTRICT
);
INSERT INTO STG_TREND (CUST_ORDER_ID,PROP_ID,SCHEDULE_STATE,COMPONENT_NAME,ORDER_ELMT_ID,
DETECTION_DATE,LAST_MODIFIED,MIN_PROJ_STATE,AVG_PROJ_STATE,MAX_PROJ_STATE,MIN_PROJ_DATE,AVG_PROJ_DATE,
MAX_PROJ_DATE,TREND_TYPE) SELECT CUST_ORDER_ID,PROP_ID,SCHEDULE_STATE,COMPONENT_NAME,ORDER_ELMT_ID,
DETECTION_DATE,LAST_MODIFIED,MIN_PROJ_STATE,AVG_PROJ_STATE,MAX_PROJ_STATE,MIN_PROJ_DATE,AVG_PROJ_DATE,
MAX_PROJ_DATE,1 FROM TREND;

DROP INDEX TREND_UNIQUE; 

DROP TABLE TREND;
CREATE TABLE TREND(
    CUST_ORDER_ID      BIGINT         NOT NULL,
    PROP_ID            BIGINT         NOT NULL,
    SCHEDULE_STATE     VARCHAR(32)    NOT NULL,
    COMPONENT_NAME     VARCHAR(127)   NOT NULL,
    ORDER_ELMT_ID      BIGINT         NOT NULL,
    DETECTION_DATE     TIMESTAMP,
    LAST_MODIFIED      TIMESTAMP,
    MIN_PROJ_STATE     SMALLINT,
    AVG_PROJ_STATE     SMALLINT,
    MAX_PROJ_STATE     SMALLINT,
    MIN_PROJ_DATE      TIMESTAMP,
    AVG_PROJ_DATE      TIMESTAMP,
    MAX_PROJ_DATE      TIMESTAMP,
    TAP_START_DATE     TIMESTAMP,
    TAP_END_DATE       TIMESTAMP,
    TAP_TOT_DATA_PTS   INTEGER,
    TREND_TYPE         SMALLINT       NOT NULL,
    CONSTRAINT TREND_PROP FOREIGN KEY (PROP_ID) REFERENCES PROP_DEF (PROP_ID),
    CONSTRAINT TREND_OE FOREIGN KEY (ORDER_ELMT_ID) REFERENCES ORDER_ELMT (ORDER_ELMT_ID) ON DELETE RESTRICT ON UPDATE RESTRICT,
    CONSTRAINT TREND_CO FOREIGN KEY (CUST_ORDER_ID) REFERENCES CUST_ORDER (CUST_ORDER_ID) ON DELETE RESTRICT ON UPDATE RESTRICT
);
INSERT INTO TREND SELECT * FROM STG_TREND;
UPDATE TREND SET TAP_END_DATE=DETECTION_DATE;
DROP TABLE STG_TREND;

CREATE UNIQUE INDEX TREND_UNIQUE ON TREND (CUST_ORDER_ID,PROP_ID,SCHEDULE_STATE,COMPONENT_NAME,ORDER_ELMT_ID,MIN_PROJ_DATE,AVG_PROJ_DATE,MAX_PROJ_DATE,TREND_TYPE);

ALTER TABLE METRIC
ADD TOT_VALUE DOUBLE PRECISION;
UPDATE METRIC SET TOT_VALUE=-1;	

UPDATE METRIC SET TOT_VALUE=AVG_VALUE,AVG_VALUE=-1 WHERE METRIC.PROP_ID IN (SELECT METRIC_DEF.PROP_ID FROM METRIC_DEF WHERE METRIC_DEF.EVALUATOR_TYPE=5);

UPDATE CUST_ORDER SET CUST_ORDER_NAME = CHAR(CUST_ORDER_ID);
UPDATE CUST_ORDER SET CUST_ORDER_NAME = RTRIM(CUST_ORDER_NAME);

drop view msched_view;

create view msched_view as
select 
       schedule.name as schedule_name,
       metric.prop_id as m_prop_id,
       metric.offrg_elmt_id,
       metric.schedule_state,
       metric.type as metric_type,
       metric.optimal_value,
       metric.desirable_value,
       metric.breach_count,
       metric.optimal_count,
       metric.desirable_count,
       metric.count_per_resource,
       metric.window_size,
       metric.window_unit,
       metric.is_internal as m_is_internal,
       metric.description as mv_description,
       metric.show_subscriber,
       metric.min_value,
       metric.max_value,
       metric.avg_value,
       metric.operator,
       metric.tot_value
from metric left outer join schedule on metric.schedule_id = schedule.schedule_id;


drop view elmt_mprop_view;

create view elmt_mprop_view as 
select  
        elmt_mprop_offrgid_view.svc_elmt_id,  
	elmt_mprop_offrgid_view.sem_id, 
	elmt_mprop_offrgid_view.svc_scope_id,
        elmt_mprop_offrgid_view.pd_prop_id, 
        elmt_mprop_offrgid_view.pd_name, 
        elmt_mprop_offrgid_view.usage, 
        elmt_mprop_offrgid_view.set_by,
        coalesce (msched_view.show_subscriber, elmt_mprop_offrgid_view.show_subscriber) AS show_subscriber,
        elmt_mprop_offrgid_view.category, 
        elmt_mprop_offrgid_view.pd_description, 
        elmt_mprop_offrgid_view.prop_display, 
        elmt_mprop_offrgid_view.md_name, 
	elmt_mprop_offrgid_view.data_type, 
	elmt_mprop_offrgid_view.units, 
	elmt_mprop_offrgid_view.md_is_internal,
	elmt_mprop_offrgid_view.value_constraints,
	elmt_mprop_offrgid_view.metric_action,
	elmt_mprop_offrgid_view.evaluator_type,
	elmt_mprop_offrgid_view.metric_type as md_type,
        elmt_mprop_offrgid_view.offrg_elmt_id, 
	elmt_mprop_offrgid_view.measurement_type_id,
        msched_view.schedule_name,
        msched_view.m_prop_id,
        msched_view.schedule_state,
        msched_view.metric_type,
        msched_view.optimal_value,
        msched_view.desirable_value,
        msched_view.breach_count,
        msched_view.optimal_count,
        msched_view.desirable_count,
        msched_view.count_per_resource,
        msched_view.window_size,
        msched_view.window_unit,
        msched_view.m_is_internal,
        msched_view.mv_description,
	msched_view.min_value,
	msched_view.max_value,
	msched_view.avg_value,
	msched_view.operator,
	msched_view.tot_value
from 
	elmt_mprop_offrgid_view left outer join msched_view 
	on (elmt_mprop_offrgid_view.pd_prop_id = msched_view.m_prop_id and 
	    elmt_mprop_offrgid_view.offrg_elmt_id = msched_view.offrg_elmt_id); 


UPDATE SCHEDULE_MILESTONE SET TIME = -1;

UPDATE METRIC_DEF SET METRIC_ACTION=1 WHERE EVALUATOR_TYPE=5;

INSERT INTO MM.Extract_Filter (ExtFltr_Cd, ExtFltr_Nm, ExtFltr_Flg) VALUES ('MODEL1', 'Tivoli Common Data Model v1', 'N');

INSERT INTO MM.Extract_Filter (ExtFltr_Cd, ExtFltr_Nm, ExtFltr_Flg) VALUES ('AMW', 'IBM Tivoli Monitoring', 'N');

CREATE INDEX I_CUST_ORD_ID ON AGREEMENT_VIOL (CUST_ORDER_ID);
