------------------------------------------------------------------------
--
-- Tivoli Enterprise Data Warehouse, v 1.1.0
-- (C) Copyright IBM Corp. 2002.  All Rights Reserved.
--
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with
-- IBM Corp.
--
--
------------------------------------------------------------------------
--
-- File Information: src/tools/sql/twh_cdw_data.sql, twh_core, twh_1.2
--
-- Revision: 1.14
--
-- Date: 8/9/02 13:22:47
--
-- Description: This is a common file for inserting static data
-- into the CDW. All application installs should place this file in their
-- /tedw/ava_code/v110/cdw/dml directory.
--
------------------------------------------------------------------------

-- All data is initially inserted into a temporary table that has
-- the same columns as the target table in the CDW.
-- That table is then inserted into the CDW table with a "where not exists"
-- clause. This insures that duplicate data is not inserted and an
-- error is not generated for trying to insert duplicate data.

declare global temporary table comptyp (
       CompTyp_Cd           CHAR(17) NOT NULL,
       CompTyp_Parent_Cd    CHAR(17),
       CompTyp_Nm           VARCHAR(120) NOT NULL,
       CompTyp_Strt_DtTm    TIMESTAMP NOT NULL,
       CompTyp_End_DtTm     TIMESTAMP NOT NULL
)
with replace on commit preserve rows not logged
;

--Insert all time values in UTC
insert into session.comptyp values ('IP_HOST', NULL, 'IP Host', current timestamp - current timezone, '9999-01-01-12.00.00.000000');

insert into session.comptyp values ('IP_INTERFACE', NULL, 'IP Interface', current timestamp - current timezone, '9999-01-01-12.00.00.000000');

insert into session.comptyp values ('TME_ENDPOINT', NULL, 'Tivoli endpoint', current timestamp - current timezone, '9999-01-01-12.00.00.000000');

insert into twg.comptyp
select * from session.comptyp s
where not exists (
  select 1 from
  twg.comptyp t where
  t.comptyp_cd = s.comptyp_cd
);

--
-- Insert component relation type codes
--
declare global temporary table RelnTyp (
       RelnTyp_Cd           CHAR(6) NOT NULL,
       RelnTyp_Nm           VARCHAR(120) NOT NULL)
with replace on commit preserve rows not logged
;

insert into session.RelnTyp values (
  'PCHILD', 'Parent Child Relation'
);
insert into session.RelnTyp values (
  'MEMBER', 'Member Relation'
);
insert into session.RelnTyp values (
  'OWNS', 'Owns Relation'
);
insert into session.RelnTyp values (
  'CNTRLS', 'Controls Relation'
);
insert into session.RelnTyp values (
  'NETWRK', 'Network Relation'
);
insert into session.RelnTyp values (
  'RUNSON', 'Runs on Relation'
);
insert into session.RelnTyp values (
  'INVOKE', 'Invoke Relation'
);
insert into session.RelnTyp values (
  'DEPEND', 'Depend Relation'
);
insert into session.RelnTyp values (
  'PCONT', 'Physical Containment Relation'
);

insert into twg.RelnTyp
select * from session.RelnTyp s
where not exists (
  select 1 from
  twg.RelnTyp t where
  t.RelnTyp_Cd = s.RelnTyp_Cd
);


--
-- Insert time summary codes
--
declare global temporary table tmsum (
  TmSum_Cd             CHAR NOT NULL,
  TmSum_Nm             VARCHAR(120) NOT NULL
)
with replace on commit preserve rows not logged
;

insert into session.tmsum values ('H', 'Hourly');
insert into session.tmsum values ('D', 'Daily');
insert into session.tmsum values ('W', 'Weekly');
insert into session.tmsum values ('M', 'Monthly');
insert into session.TmSum values ('Q', 'Quarterly');
insert into session.TmSum values ('Y', 'Yearly');
insert into session.TmSum values ('P', 'Point');

insert into twg.tmsum
select * from session.tmsum s
where not exists (
  select 1 from
  twg.tmsum t where
  t.TmSum_Cd = s.TmSum_Cd
);


--
-- Insert measurement unit codes
--
declare global temporary table munitcat (
  MUnitCat_Cd          CHAR(6) NOT NULL,
  MUnitCat_Nm          VARCHAR(120) NOT NULL
)
with replace on commit preserve rows not logged
;

insert into session.munitcat values ('TM','Time Duration');
insert into session.munitcat values ('QTY','Quantity');
insert into session.munitcat values ('PRC','Percentage');
insert into session.munitcat values ('RT','Rate');

insert into twg.munitcat
select * from session.munitcat s
where not exists (
  select 1 from
  twg.munitcat t where
  t.munitcat_Cd = s.munitcat_Cd
);


--
-- Insert measurement units
--
declare global temporary table munit (
  MUnit_Cd             CHAR(6) NOT NULL,
  MUnitCat_Cd          CHAR(6),
  MUnit_Nm             VARCHAR(120) NOT NULL
)
with replace on commit preserve rows not logged
;

insert into session.MUnit values ('PRC', 'PRC', 'Percentage');
insert into session.MUnit values ('Bps', 'RT', 'Bytes per second');
insert into session.MUnit values ('MBps', 'RT', 'Megabytes per second');
insert into session.MUnit values ('KBps', 'RT', 'Kilobytes per second');
insert into session.MUnit values ('Rps', 'RT', 'Requests per second');
insert into session.MUnit values ('Qps', 'RT', 'Quantity per sec');
insert into session.MUnit values ('Qpm', 'RT', 'Quantity per minute');
insert into session.MUnit values ('QTY', 'QTY', 'Quantity');
insert into session.MUnit values ('GB', 'QTY', 'gigabytes');
insert into session.MUnit values ('KB', 'QTY', 'kilobytes');
insert into session.MUnit values ('MB', 'QTY', 'megabytes');
insert into session.MUnit values ('B', 'QTY', 'bytes');
insert into session.MUnit values ('4KPgs', 'QTY', '4K pages');
insert into session.MUnit values ('MSec', 'TM', 'milliseconds');
insert into session.MUnit values ('Sec', 'TM', 'seconds');
insert into session.MUnit values ('Min', 'TM', 'minutes');
insert into session.MUnit values ('Hr', 'TM', 'hours');
insert into session.MUnit values ('Day', 'TM', 'days');
insert into session.MUnit values ('HSc', 'TM', 'Hundredths of a second');

insert into twg.munit
select * from session.munit s
where not exists (
  select 1 from
  twg.munit t where
  t.munit_Cd = s.munit_Cd
);


--
-- Insert measurement group type codes
--
declare global temporary table mgrptyp (
  MGrpTyp_Cd           CHAR(6) NOT NULL,
  MGrpTyp_Nm           VARCHAR(120) NOT NULL
)
with replace on commit preserve rows not logged
;

insert into session.MgrpTyp values ('STATE','State');
insert into session.MgrpTyp values ('CATEG','Category');
insert into session.mgrptyp values ('GROUP', 'Aggregate Types or Group Functions');
insert into session.MgrpTyp values ('TRANS','State Transition Groups');

insert into twg.mgrptyp
select * from session.mgrptyp s
where not exists (
  select 1 from
  twg.mgrptyp t where
  t.mgrptyp_Cd = s.mgrptyp_Cd
);


--
-- Insert measurement groups
--
declare global temporary table mgrp (
  MGrp_Cd              CHAR(6) NOT NULL,
  MGrpTyp_Cd           CHAR(6) NOT NULL,
  MGrp_Parent_Cd       CHAR(6),
  MGrp_Nm              VARCHAR(120) NOT NULL
)
with replace on commit preserve rows not logged
;

insert into session.MGrp values ('PERF','CATEG', NULL, 'Performance');
insert into session.MGrp values ('UTIL','CATEG', NULL, 'Utilization');
insert into session.MGrp values ('AVL','CATEG', NULL, 'Availability');
insert into session.MGrp values ('STATE','CATEG', NULL, 'Percentage State measurements');
insert into session.MGrp values ('STORAG','CATEG', NULL, 'Storage');
insert into session.MGrp values ('AVG_E', 'GROUP', NULL, 'Average value exists');
insert into session.MGrp values ('MIN_E', 'GROUP', NULL, 'Minimum value exists');
insert into session.MGrp values ('MAX_E', 'GROUP', NULL, 'Maximum value exists');
insert into session.MGrp values ('TOT_E', 'GROUP', NULL, 'Total value exists');

insert into twg.mgrp
select * from session.mgrp s
where not exists (
  select 1 from
  twg.mgrp t where
  t.mgrp_Cd = s.mgrp_Cd
);


--
-- Insert measurement source codes
--
declare global temporary table msrc (
  MSrc_Cd              CHAR(6) NOT NULL,
  MSrc_Parent_Cd       CHAR(6),
  MSrc_Nm              VARCHAR(120) NOT NULL
)
with replace on commit preserve rows not logged
;

insert into session.msrc values ('Tivoli', NULL, 'Tivoli Application');
insert into session.msrc values ('MODEL1', NULL, 'Tivoli Common Data Model v1');

insert into twg.msrc
select * from session.msrc s
where not exists (
  select 1 from
  twg.msrc t where
  t.msrc_Cd = s.msrc_Cd
);


--
-- Insert measurement type codes
--
declare global temporary table MsmtTyp (
  MsmtTyp_ID           INTEGER NOT NULL,
  MUnit_Cd             CHAR(6) NOT NULL,
  MSrc_Cd              CHAR(6) NOT NULL,
  MsmtTyp_Nm           VARCHAR(120) NOT NULL,
  MsmtTyp_Ds           VARCHAR(254)
)
with replace on commit preserve rows not logged
;

insert into session.MsmtTyp values (0, 'Min','MODEL1','Available', 'The amount of time that the resource is available');
;
insert into session.MsmtTyp values (0, 'Min','MODEL1','Degrading', 'The amount of time that the resource is degrading');
;
insert into session.MsmtTyp values (0, 'Min','MODEL1','Unavailable', 'The amount of time that the resource is unavailable');
;
insert into session.MsmtTyp values (0, 'Min','MODEL1','Unreachable', 'The amount of time that the resource is unreachable');
;
insert into session.MsmtTyp values (0, 'Min','MODEL1','Responding', 'The amount of time that it took to detect, isolate, and respond to a problem with the resource');
;
insert into session.MsmtTyp values (0, 'Min','MODEL1','Repairing', 'The amount of time that it took to fix the problem associated with the resource');
;
insert into session.MsmtTyp values (0, 'Min','MODEL1','Closing', 'The amount of time that it took to close the problem with the resource');
;
insert into session.MsmtTyp values (0, 'Min','MODEL1','Unknown', 'The amount of time that the state of the resource is unknown');
;
insert into session.MsmtTyp values (0, 'Min','MODEL1','Unmanaged', 'The amount of time that the resource is unmanaged');
;

insert into twg.MsmtTyp
select * from session.MsmtTyp s
where not exists (
  select 1 from
  twg.MsmtTyp t where
  t.MsmtTyp_Nm = s.MsmtTyp_Nm
);


--
-- Insert measurement rules
--
declare global temporary table MsmtRul (
  CompTyp_Cd           CHAR(17) NOT NULL,
  MsmtTyp_ID           INTEGER NOT NULL
)
with replace on commit preserve rows not logged
;

insert into session.MsmtRul
  select 'IP_HOST', MsmtTyp_ID from twg.MsmtTyp where MsmtTyp_Nm in (
    'Available',
    'Degrading',
    'Unavailable',
    'Unreachable',
    'Responding',
    'Repairing',
    'Closing',
    'Unknown',
    'Unmanaged'
  )
;

insert into session.MsmtRul
  select 'IP_INTERFACE', MsmtTyp_ID from twg.MsmtTyp where MsmtTyp_Nm in (
    'Available',
    'Degrading',
    'Unavailable',
    'Unreachable',
    'Responding',
    'Repairing',
    'Closing',
    'Unknown',
    'Unmanaged'
  )
;

insert into session.MsmtRul
  select 'TME_ENDPOINT', MsmtTyp_ID from twg.MsmtTyp where MsmtTyp_Nm in (
    'Available',
    'Degrading',
    'Unavailable',
    'Unreachable',
    'Responding',
    'Repairing',
    'Closing',
    'Unknown',
    'Unmanaged'
  )
;

insert into twg.MsmtRul
select * from session.MsmtRul s
where not exists (
  select 1 from
  twg.MsmtRul t where
  t.CompTyp_Cd = s.CompTyp_Cd and
  t.MsmtTyp_ID = s.MsmtTyp_ID
);


--
-- Insert Attribute Types
--
declare global temporary table AttrTyp (
       AttrTyp_Cd           CHAR(17) NOT NULL,
       AttrTyp_Nm           VARCHAR(120) NOT NULL
)
with replace on commit preserve rows not logged
;

insert into session.AttrTyp values('LAST_IP_ADDRESS','Last IP Address');
insert into session.AttrTyp values('TME_OBJECT_ID','Tivoli object ID');
insert into session.AttrTyp values('TME_LABEL','Tivoli endpoint label');
insert into session.AttrTyp values('OS_NAME', 'Operating system name');
insert into session.AttrTyp values('OS_TYPE', 'Operating system type');
insert into session.AttrTyp values('MAJOR_VERSION', 'Major version number');
insert into session.AttrTyp values('MINOR_VERSION', 'Minor version number');
insert into session.AttrTyp values('SUB_VERSION', 'Sub version number');
insert into session.AttrTyp values('VERSION', 'Version number');
insert into session.AttrTyp values('CONTACT', 'Contact name');
insert into session.AttrTyp values('MANUFACTURER', 'Manufacturer');
insert into session.AttrTyp values('MACHINE_TYPE', 'Machine type');
insert into session.AttrTyp values('MODEL', 'Machine model number');
insert into session.AttrTyp values('SERIAL_NUMBER', 'Serial number');
insert into session.AttrTyp values('IP_DOMAIN', 'IP domain');
insert into session.AttrTyp values('IP_HOSTNAME', 'IP hostname');

insert into TWG.AttrTyp
select * from
 session.AttrTyp s
where not exists
( select 1 from
  TWG.AttrTyp t
  where
  t.AttrTyp_Cd=s.AttrTyp_Cd )
;

--
-- Insert Attribute Rules
--
declare global temporary table AttrRul (
       CompTyp_Cd           CHAR(17) NOT NULL,
       AttrTyp_Cd           CHAR(17) NOT NULL,
       AttrRul_Strt_DtTm    TIMESTAMP NOT NULL,
       AttrRul_End_DtTm     TIMESTAMP NOT NULL,
       AttrRul_Dom_Ind      CHAR NOT NULL
)
with replace on commit preserve rows not logged
;

insert into session.AttrRul values('IP_HOST','LAST_IP_ADDRESS',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_HOST','TME_OBJECT_ID',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_HOST','TME_LABEL',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_HOST','OS_NAME',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_HOST','OS_TYPE',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_HOST','MAJOR_VERSION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_HOST','MINOR_VERSION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_HOST','SUB_VERSION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_HOST','VERSION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_HOST','CONTACT',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_HOST','MANUFACTURER',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_HOST','MACHINE_TYPE',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_HOST','MODEL',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_HOST','SERIAL_NUMBER',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_HOST','IP_DOMAIN',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_HOST','IP_HOSTNAME',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');

insert into session.AttrRul values('IP_INTERFACE','TME_OBJECT_ID',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_INTERFACE','TME_LABEL',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_INTERFACE','OS_NAME',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_INTERFACE','OS_TYPE',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_INTERFACE','MAJOR_VERSION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_INTERFACE','MINOR_VERSION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_INTERFACE','SUB_VERSION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_INTERFACE','VERSION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_INTERFACE','CONTACT',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_INTERFACE','MANUFACTURER',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_INTERFACE','MACHINE_TYPE',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_INTERFACE','MODEL',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_INTERFACE','SERIAL_NUMBER',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_INTERFACE','IP_DOMAIN',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');

insert into session.AttrRul values('TME_ENDPOINT','TME_LABEL',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('TME_ENDPOINT','OS_NAME',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('TME_ENDPOINT','OS_TYPE',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('TME_ENDPOINT','MAJOR_VERSION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('TME_ENDPOINT','MINOR_VERSION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('TME_ENDPOINT','SUB_VERSION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('TME_ENDPOINT','VERSION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('TME_ENDPOINT','CONTACT',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('TME_ENDPOINT','MANUFACTURER',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('TME_ENDPOINT','MACHINE_TYPE',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('TME_ENDPOINT','MODEL',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('TME_ENDPOINT','SERIAL_NUMBER',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('TME_ENDPOINT','IP_DOMAIN',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('TME_ENDPOINT','IP_HOSTNAME',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');

insert into TWG.AttrRul
select * from
 session.AttrRul s
where not exists
( select 1 from
  TWG.AttrRul t,
  TWG.CompTyp c
  where
  t.AttrTyp_Cd=s.AttrTyp_Cd and c.CompTyp_Cd=s.CompTyp_Cd)
;
