------------------------ COPYRIGHT STATEMENT ----------------------------
--
-- Licensed Materials - Property of IBM
-- 5724-C40
-- (C) Copyright IBM Corp. 2003.  All Rights Reserved.
--
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with
-- IBM Corp.
--
------------------------END OF COPYRIGHT STATEMENT -----------------------

--------------------------------------------------------------------------
--  CMVC Location:  src/tedw_apps/dyk/etl/sql/DYK_m10_s010_Populate_SLM_Msmt_Staging.db2, etl.target, slm1.2.1.fp1
--  Version:        1.1
--  Last Modified:  7/18/03
--------------------------------------------------------------------------

--
-- Drop temporary table for enabled source apps.
--
--#IGNORE_ERROR
drop table DYK.STAGE_APPS;

--
-- Create temporary table in CDW for enabled source apps.
--
create table DYK.STAGE_APPS (
   MSRC_CD  char(6) not null
);

--
-- Move the extract filter codes for the enabled source apps. into the staging table.
--
--#INSERT_INTO_SOURCE
insert into DYK.STAGE_APPS
    SELECT 
        EA.MSRC_CD
    FROM
	DYK.ENABLED_APPS EA;

-- Drop the temporary MSMT staging table in the datamart
--#EXECUTE_AT_TARGET
--#IGNORE_ERROR
drop table DYK.STAGE_MSMT_TEMP;

-- Create the temporary MSMT staging table in the datamart
--#EXECUTE_AT_TARGET
create table DYK.STAGE_MSMT_TEMP (
    MSMT_ID             bigint not null,
    MSMTTYP_ID          integer not null,
    MSMTTYP_NM          varchar(120) not null,
    COMP_ID             integer not null,
    COMP_NM             varchar(254),
    COMPTYP_CD          char(17) not null,
    TMSUM_CD            char not null,
    MSMT_ST             timestamp not null,
    MSMT_MIN_VAL        float,
    MSMT_MAX_VAL        float,
    MSMT_AVG_VAL        float,
    MSMT_TOT_VAL        float,
    MSMT_SMPL_CNT       integer,
    MSMT_ERR_CNT        integer
);

-- Insert the MSMT data into staging table
--#INSERT_INTO_TARGET
insert into DYK.STAGE_MSMT_TEMP (
    SELECT
        TWG.MSMT.MSMT_ID AS MSMT_ID,
        TWG.MSMT.MSMTTYP_ID AS MSMTTYP_ID,
        TWG.MSMTTYP.MSMTTYP_NM AS MSMTTYP_NM,
        TWG.MSMT.COMP_ID AS COMP_ID,
        TWG.COMP.COMP_NM AS COMP_NM,
        TWG.COMP.COMPTYP_CD AS COMPTYP_CD,
        TWG.MSMT.TMSUM_CD AS TMSUM_CD,
        TIMESTAMP(TWG.MSMT.MSMT_STRT_DT,TWG.MSMT.MSMT_STRT_TM) AS TM_STAMP,
        TWG.MSMT.MSMT_MIN_VAL AS MSMT_MIN_VAL,
        TWG.MSMT.MSMT_MAX_VAL AS MSMT_MAX_VAL,
        TWG.MSMT.MSMT_AVG_VAL AS MSMT_AVG_VAL,
        TWG.MSMT.MSMT_TOT_VAL AS MSMT_TOT_VAL,
        TWG.MSMT.MSMT_SMPL_CNT AS MSMT_SMPL_CNT,
        TWG.MSMT.MSMT_ERR_CNT AS MSMT_ERR_CNT
    FROM
        TWG.COMP,
        TWG.MSMT,
	TWG.MSMTTYP
    WHERE
        (
            TWG.MSMT.COMP_ID = TWG.COMP.COMP_ID
            AND
            TWG.MSMT.MSMTTYP_ID = TWG.MSMTTYP.MSMTTYP_ID
            AND
            TWG.MSMTTYP.MSRC_CD IN (SELECT MSRC_CD FROM DYK.STAGE_APPS)
            AND
            (
               TWG.MSMT.MSMT_ID > (SELECT
                                       TWG.EXTRACT_CONTROL.EXTCTL_TO_INTSEQ
                                   FROM
                                       TWG.EXTRACT_CONTROL
                                   WHERE
                                       TWG.EXTRACT_CONTROL.EXTCTL_SOURCE = 'TWG.MSMT' AND
                                       TWG.EXTRACT_CONTROL.EXTCTL_TARGET = 'DYK.STAGE_MSMT'
                                  )
            )
        )
    );

-- Drop temporary table for groups
--#EXECUTE_AT_TARGET
--#IGNORE_ERROR
drop table DYK.STAGE_GRPS_TEMP;

-- Create temporary table for groups
--#EXECUTE_AT_TARGET
create table DYK.STAGE_GRPS_TEMP (
    MSMTTYP_ID      integer not null,
    MGRP_CD         char(6) not null,
    MGRPTYP_CD      char(6) not null
);

-- Insert group information
--#INSERT_INTO_TARGET
insert into DYK.STAGE_GRPS_TEMP (
    SELECT DISTINCT
        TWG.MGRPMBR.MSMTTYP_ID,
        TWG.MGRPMBR.MGRP_CD,
        TWG.MGRPMBR.MGRPTYP_CD
    FROM
        TWG.MGRPMBR
    WHERE
        (
            MGRP_CD IN ('TOT_E') AND
            MGRPTYP_CD = 'GROUP'
        )
	AND
	    MSMTTYP_ID NOT IN (SELECT
 		                  MSMTTYP_ID
                               FROM
                                  TWG.MGRPMBR
                               WHERE
                                  TWG.MGRPMBR.MGRPTYP_CD = 'TRANS'
                              )
);                          

--#INSERT_INTO_TARGET
insert into DYK.STAGE_GRPS_TEMP (
    SELECT DISTINCT
        TWG.MGRPMBR.MSMTTYP_ID,
        'AVG_E',
        TWG.MGRPMBR.MGRPTYP_CD
    FROM
        TWG.MGRPMBR
    WHERE
        (
            MGRP_CD IN ('MIN_E','MAX_E','AVG_E') AND
            MGRPTYP_CD = 'GROUP'
        )
	AND
	    MSMTTYP_ID NOT IN (SELECT
 		                  MSMTTYP_ID
                               FROM
                                  TWG.MGRPMBR
                               WHERE
                                  TWG.MGRPMBR.MGRPTYP_CD = 'TRANS'
                              )
);                          

-- Insert group information
--#INSERT_INTO_TARGET
insert into DYK.STAGE_GRPS_TEMP (
    SELECT DISTINCT
        TWG.MGRPMBR.MSMTTYP_ID,
        'AVL',
        TWG.MGRPMBR.MGRPTYP_CD
    FROM
        TWG.MGRPMBR
    WHERE
        (
            MGRPTYP_CD = 'TRANS'
        )
	AND
	    MSMTTYP_ID IN (SELECT
                              MSMTTYP_ID
                           FROM
                              TWG.MSMTTYP
                           WHERE
                              TWG.MSMTTYP.MSRC_CD = 'MODEL1'
                          )
);                          

-- Drop the staging table in the datamart
--#EXECUTE_AT_TARGET
--#IGNORE_ERROR
drop table DYK.STAGE_MSMT;

-- Create the staging table in the datamart
--#EXECUTE_AT_TARGET
CREATE TABLE DYK.STAGE_MSMT (
    MSMT_ID             BIGINT NOT NULL,
    MSMTTYP_ID          INTEGER NOT NULL,
    MSMTTYP_NM          VARCHAR(120) NOT NULL,
    COMP_ID             INTEGER NOT NULL,
    COMP_NM             VARCHAR(254),
    COMPTYP_CD          CHAR(17) NOT NULL,
    TMSUM_CD            CHAR NOT NULL,
    MSMT_ST             TIMESTAMP NOT NULL,
    MSMT_MIN_VAL        FLOAT,
    MSMT_MAX_VAL        FLOAT,
    MSMT_AVG_VAL        FLOAT,
    MSMT_TOT_VAL        FLOAT,
    MSMT_SMPL_CNT       INTEGER,
    MSMT_ERR_CNT        INTEGER,
    MGRP_CD             CHAR(6) NOT NULL,
    MGRPTYP_CD          CHAR(6) NOT NULL
) IN STG_MSMT;

-- Populate the staging table in the datamart
--#EXECUTE_AT_TARGET
insert into DYK.STAGE_MSMT (
    SELECT
        DYK.STAGE_MSMT_TEMP.MSMT_ID AS MSMT_ID,
        DYK.STAGE_MSMT_TEMP.MSMTTYP_ID AS MSMTTYP_ID,
        DYK.STAGE_MSMT_TEMP.MSMTTYP_NM AS MSMTTYP_NM,
        DYK.STAGE_MSMT_TEMP.COMP_ID AS COMP_ID,
        DYK.STAGE_MSMT_TEMP.COMP_NM AS COMP_NM,
        DYK.STAGE_MSMT_TEMP.COMPTYP_CD AS COMPTYP_CD,
        DYK.STAGE_MSMT_TEMP.TMSUM_CD AS TMSUM_CD,
        DYK.STAGE_MSMT_TEMP.MSMT_ST AS TM_STAMP,
        DYK.STAGE_MSMT_TEMP.MSMT_MIN_VAL AS MSMT_MIN_VAL,
        DYK.STAGE_MSMT_TEMP.MSMT_MAX_VAL AS MSMT_MAX_VAL,
        DYK.STAGE_MSMT_TEMP.MSMT_AVG_VAL AS MSMT_AVG_VAL,
        DYK.STAGE_MSMT_TEMP.MSMT_TOT_VAL AS MSMT_TOT_VAL,
        DYK.STAGE_MSMT_TEMP.MSMT_SMPL_CNT AS MSMT_SMPL_CNT,
        DYK.STAGE_MSMT_TEMP.MSMT_ERR_CNT AS MSMT_ERR_CNT,
        DYK.STAGE_GRPS_TEMP.MGRP_CD AS MGRP_CD,
        DYK.STAGE_GRPS_TEMP.MGRPTYP_CD AS MGRPTYP_CD
    FROM
        DYK.STAGE_MSMT_TEMP,
        DYK.STAGE_GRPS_TEMP
    WHERE
        (
            DYK.STAGE_MSMT_TEMP.MSMTTYP_ID = DYK.STAGE_GRPS_TEMP.MSMTTYP_ID
        )
    );

